@@ -2,9 +2,7 @@ import discord
 from discord.ext import commands
 from name_that_hash import runner
 import json
-import cracking
-import hashsearch
-
+from search_that_hash import main
 
 bot = commands.Bot(command_prefix='!')
 
@@ -27,4 +25,5 @@ async def hash(ctx, hash):
         embed_types.add_field(name=types[i]['name'], value=types[i]['description'], inline=False)
     await ctx.send(embed=embed_types)
 
-bot.run('MzM0NzExNTYzMzI1ODAwNDU5.WWY6bw.kpE4pBua63XpIYJxvVyYHIINvz8')
\ No newline at end of file
+    print(main.return_as_fast_json(hash))
+bot.run('MzM0NzExNTYzMzI1ODAwNDU5.WWY6bw.20Ta-ohVLf6n7wMbFR6XmocopNU')
\ No newline at end of file
