@@ -116,9 +116,11 @@ def return_as_json(hashes):
     config["hashes"] = create_hash_config(config)
     config["api"] = False
 
-    searcher = cracking.Searcher(config)
-
-    return json.dumps(cracking.Searcher.main(searcher))
+    try:
+        searcher = cracking.Searcher(config)
+        return json.dumps(cracking.Searcher.main(searcher))
+    except:
+        return False
 
 def return_as_fast_json(hashes):
 
@@ -135,9 +137,11 @@ def return_as_fast_json(hashes):
     config["hashes"] = create_hash_config(config)
     config["api"] = True
 
-    searcher = cracking.Searcher(config)
-
-    print(cracking.Searcher.main(searcher))
+    try:
+        searcher = cracking.Searcher(config)
+        return json.dumps(cracking.Searcher.main(searcher))
+    except:
+        return False
         
 
 def create_hash_config(config):
