@@ -21,7 +21,7 @@ class hashcat:
                             stdout=sp.DEVNULL,
                             stderr=sp.STDOUT
                         )
-                    except sp.CalledProcessError as error:
+                    except:
                         return("Failed")
                         continue
 
@@ -43,7 +43,7 @@ class hashcat:
                             stdout=sp.DEVNULL,
                             stderr=sp.STDOUT
                         )
-                    except sp.CalledProcessError as error:
+                    except:
                         return("Failed")
                         continue
 
@@ -66,7 +66,7 @@ class hashcat:
                             shell="True",
                             cwd=hash[7], 
                         )
-                    except sp.CalledProcessError as error:
+                    except:
                         return("Failed")
                         continue
 
@@ -75,8 +75,6 @@ class hashcat:
                             f"{command} --show", shell=True, cwd=hash[7]
                         ).strip()
                     ).strip("'")
-
-                    print(possible_output)
     
                     if not "No hashes loaded." in possible_output:
                         return possible_output.split(":")[1]
@@ -88,7 +86,7 @@ class hashcat:
                             command,
                             shell="True",
                         )
-                    except sp.CalledProcessError as error:
+                    except:
                         return("Failed")
                         continue
             
